@@ -1,4 +1,4 @@
 from graphio.objects.nodeset import NodeSet
 from graphio.objects.relationshipset import RelationshipSet
 from graphio.objects.datacontainer import Container
-from graphio.model import ModelNode, ModelRelationship, MergeKey, Label
\ No newline at end of file
+from graphio.model import ModelNode, ModelRelationship, MergeKey, Label, NodeDescriptor
\ No newline at end of file
